"""Auto-generated endpoint constants.

Do not edit manually; regenerate with tools/generate_endpoints.py
"""


WORKSPACE_2_0_ENDPOINTS = {
    "cluster_policies_create": "/api/2.0/policies/clusters/create",
    "cluster_policies_delete": "/api/2.0/policies/clusters/delete",
    "cluster_policies_edit": "/api/2.0/policies/clusters/edit",
    "cluster_policies_get": "/api/2.0/policies/clusters/get",
    "cluster_policies_list": "/api/2.0/policies/clusters/list",
    "clusters_create": "/api/2.0/clusters/create",
    "clusters_delete": "/api/2.0/clusters/delete",
    "clusters_edit": "/api/2.0/clusters/edit",
    "clusters_events": "/api/2.0/clusters/events",
    "clusters_get": "/api/2.0/clusters/get",
    "clusters_list": "/api/2.0/clusters/list",
    "clusters_permanent_delete": "/api/2.0/clusters/permanent-delete",
    "clusters_restart": "/api/2.0/clusters/restart",
    "clusters_start": "/api/2.0/clusters/start",
    "dbfs_delete": "/api/2.0/dbfs/delete",
    "dbfs_get_status": "/api/2.0/dbfs/get-status",
    "dbfs_list": "/api/2.0/dbfs/list",
    "dbfs_mkdirs": "/api/2.0/dbfs/mkdirs",
    "dbfs_read": "/api/2.0/dbfs/read",
    "instance_pools_create": "/api/2.0/instance-pools/create",
    "instance_pools_delete": "/api/2.0/instance-pools/delete",
    "instance_pools_edit": "/api/2.0/instance-pools/edit",
    "instance_pools_get": "/api/2.0/instance-pools/get",
    "instance_pools_list": "/api/2.0/instance-pools/list",
    "permissions_clusters_get": "/api/2.0/permissions/clusters/{cluster_id}",
    "permissions_clusters_patch": "/api/2.0/permissions/clusters/{cluster_id}",
    "permissions_clusters_permission_levels": "/api/2.0/permissions/clusters/{cluster_id}/permissionLevels",
    "permissions_jobs_get": "/api/2.0/permissions/jobs/{job_id}",
    "permissions_jobs_patch": "/api/2.0/permissions/jobs/{job_id}",
    "permissions_jobs_permission_levels": "/api/2.0/permissions/jobs/{job_id}/permissionLevels",
    "permissions_repos_get": "/api/2.0/permissions/repos/{repo_id}",
    "permissions_repos_patch": "/api/2.0/permissions/repos/{repo_id}",
    "permissions_repos_permission_levels": "/api/2.0/permissions/repos/{repo_id}/permissionLevels",
    "repos_create": "/api/2.0/repos",
    "repos_delete": "/api/2.0/repos/{repo_id}",
    "repos_get": "/api/2.0/repos/{repo_id}",
    "repos_list": "/api/2.0/repos",
    "repos_update": "/api/2.0/repos/{repo_id}",
    "secret_scopes_create": "/api/2.0/secrets/scopes/create",
    "secret_scopes_delete": "/api/2.0/secrets/scopes/delete",
    "secret_scopes_list": "/api/2.0/secrets/scopes/list",
    "secrets_put": "/api/2.0/secrets/put",
    "sql_warehouses_create": "/api/2.0/sql/warehouses",
    "sql_warehouses_delete": "/api/2.0/sql/warehouses/{warehouse_id}",
    "sql_warehouses_edit": "/api/2.0/sql/warehouses/{warehouse_id}/edit",
    "sql_warehouses_get": "/api/2.0/sql/warehouses/{warehouse_id}",
    "sql_warehouses_list": "/api/2.0/sql/warehouses",
    "token_create": "/api/2.0/token/create",
    "token_delete": "/api/2.0/token/delete",
    "token_list": "/api/2.0/token/list",
    "token_revoke": "/api/2.0/token/delete",
}

WORKSPACE_2_1_ENDPOINTS = {
    "jobs_create": "/api/2.1/jobs/create",
    "jobs_delete": "/api/2.1/jobs/delete",
    "jobs_get": "/api/2.1/jobs/get",
    "jobs_list": "/api/2.1/jobs/list",
    "jobs_reset": "/api/2.1/jobs/reset",
    "jobs_run_now": "/api/2.1/jobs/run-now",
    "jobs_runs_cancel": "/api/2.1/jobs/runs/cancel",
    "jobs_runs_cancel_all": "/api/2.1/jobs/runs/cancel-all",
    "jobs_runs_delete": "/api/2.1/jobs/runs/delete",
    "jobs_runs_export": "/api/2.1/jobs/runs/export",
    "jobs_runs_get": "/api/2.1/jobs/runs/get",
    "jobs_runs_get_output": "/api/2.1/jobs/runs/get-output",
    "jobs_runs_list": "/api/2.1/jobs/runs/list",
    "jobs_runs_repair": "/api/2.1/jobs/runs/repair",
    "jobs_runs_submit": "/api/2.1/jobs/runs/submit",
    "unity_catalog_catalogs_get": "/api/2.1/unity-catalog/catalogs/{catalog_name}",
    "unity_catalog_catalogs_list": "/api/2.1/unity-catalog/catalogs",
    "unity_catalog_schemas_get": "/api/2.1/unity-catalog/schemas/{full_name}",
    "unity_catalog_schemas_list": "/api/2.1/unity-catalog/schemas",
}

WORKSPACE_PREVIEW_ENDPOINTS = {
}
